<?php

declare(strict_types=1);

namespace Drupal\css_custom_properties;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Generates CSS styles for custom colors.
 */
class CustomPropsManager implements CustomPropsManagerInterface {

  /**
   * Constructs a StyleGeneratorService object.
   */
  public function __construct(
    private readonly ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getStyles(): string {
    $config = $this->configFactory->get('css_custom_properties.settings');
    $prefix = $config->get('custom_property_prefix');
    $styles = '';

    foreach ($config->get('properties') as $property_id => $property_info) {
      $property = str_replace('_', '-', $property_id);
      $styles .= "--{$prefix}-{$property}: {$property_info['color']};";
    }

    return ":root { {$styles} };";
  }

  /**
   * {@inheritdoc}
   */
  public function generateStyleTag(string $id): array {
    $style_element = [
      '#tag' => 'style',
      '#attributes' => ['media' => 'all'],
      '#value' => $this->getStyles(),
    ];

    return [$style_element, $id];
  }

}
